
#ifndef _GDFONTL_H_
#define _GDFONTL_H_ 1

/*
	This is a header file for gd font, generated using
	bdftogd version 0.60 by Jan Pazdziora, adelton@fi.muni.cz
	from bdf font
	-Gemini-Fixed-Medium-R-Normal--15-140-75-75-C-90-KOI8-U
	at Tue Jan 29 07:24:09 2002.
	The original bdf was holding following copyright:
	"Copyright (C) 1994 Cronyx Ltd."
 */


#include "gd.h"

extern gdFontPtr gdFontLarge;

#endif

